@@ -236,8 +236,9 @@ var identities = config.macros.TiddlySpaceIdentities = {
 		config.extensions.formMaker.make(container, identities.template, uri, {
 			beforeSubmit: function(ev, form) {
 				var openid = $("[name=openid]").val();
-				$('<input name="tiddlyweb_redirect" />').attr("type", "hidden").
-					val("%0#auth:OpenID=%1".format(tweb.serverPrefix, openid)).appendTo(form);
+				$('<input name="tiddlyweb_redirect" type="hidden" />')
+					.val("%0#auth:OpenID=%1".format(tweb.serverPrefix, openid))
+					.appendTo(form);
 			}, locale: admin.locale.identities });
 	}
 };
